Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2258)

Unified Diff: content/public/browser/dom_storage_context.h

Issue 2403713002: Add suborigin logic to url::Origin (Closed)
Patch Set: Fix unit test Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/url_schemes.cc ('k') | content/public/common/origin_util.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/dom_storage_context.h
diff --git a/content/public/browser/dom_storage_context.h b/content/public/browser/dom_storage_context.h
index a4aba1e91e1b4f384a0e0eaa9891b8d6e062965c..61b2856717a2fc2b118dcff5a4522d4525cefb7b 100644
--- a/content/public/browser/dom_storage_context.h
+++ b/content/public/browser/dom_storage_context.h
@@ -39,8 +39,14 @@ class DOMStorageContext {
virtual void GetSessionStorageUsage(
const GetSessionStorageUsageCallback& callback) = 0;
- // Deletes the local storage data for the given origin.
- virtual void DeleteLocalStorage(const GURL& origin) = 0;
+ // Deletes the local storage data for the physical origin of |origin_url|,
+ // including all suborigins at the physical origin.
+ //
+ // See https://w3c.github.io/webappsec-suborigins/.
+ virtual void DeleteLocalStorageForPhysicalOrigin(const GURL& origin_url) = 0;
+
+ // Deletes the local storage for the origin of |origin_url|.
+ virtual void DeleteLocalStorage(const GURL& origin_url) = 0;
// Deletes the session storage data identified by |usage_info|.
virtual void DeleteSessionStorage(
« no previous file with comments | « content/common/url_schemes.cc ('k') | content/public/common/origin_util.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698